import { defineStore } from 'pinia'
import { getUserInfo, logout } from '@/api/base'
import type { IInfo, IPermissions } from '@/types'
interface IUserType {
  info: IInfo | null
  permissions: IPermissions[]
  roles: []
}

export const useInfoStore = defineStore({
  id: 'map',
  state: (): IUserType => {
    return {
      info: null,
      permissions: [],
      roles: []
    }
  },
  getters: {
    isLogin: state => !!state.info,
    userName: ({ info }) => {
      if (!info) return ''
      return info.name || info.username || ''
    }
  },
  actions: {
    async getUserInfo() {
      const res = await getUserInfo()
      this.info = res.data.info
      this.permissions = res.data.permissions || []
      this.roles = res.data.roles || []
    },
    async logout() {
      await logout()
      this.info = null
    }
  }
})
